@@ -1,6 +1,6 @@
 ##
 ## R package reda by Wenjie Wang, Haoda Fu, and Jun Yan
-## Copyright (C) 2015-2019
+## Copyright (C) 2015-2020
 ##
 ## This file is part of the R package reda.
 ##
@@ -54,11 +54,6 @@ NULL
 ##' This is a successor function of the deprecated function \code{Survr}.  See
 ##' the vignette by `vignette("reda-Recur")` for details.
 ##'
-##' @usage
-##'
-##' Recur(time, id, event, terminal, origin,
-##'       check = c("hard", "soft", "none"), ...)
-##'
 ##' @param time A numerical vector representing the time of reccurence event or
 ##'     censoring, or a list with elements named \code{"time1"} and
 ##'     \code{"time2"} for specifying the follow-up of recurrent events.  In the
@@ -272,10 +267,6 @@ Recur <- function(time, id, event, terminal, origin,
 ##' attributions if some rows of the contained data (in the \code{.Data} slot)
 ##' have been removed by such as \code{na.action}.
 ##'
-##' @usage
-##'
-##' check_Recur(x, check = c("hard", "soft", "none"))
-##'
 ##' @inheritParams Recur
 ##' @param x An \code{Recur} object.
 ##'
@@ -457,11 +448,12 @@ setMethod(f = "as.character", signature = "Recur",
               fmt <- sprintf("(%s.%df, %s.%df%s]",
                              "%", sigMax, "%", sigMax, "%s")
               sorted_dat <- x@.Data[x@ord, , drop = FALSE]
+              sorted_id <- x@ID[x@ord]
               ## get options on max print
               max_print <- max(2L, as.integer(getOption("reda.Recur.maxPrint")))
               ## create a character vector representing the recurrent events
               char_rec <- tapply(
-                  seq_along(x@ord), x@ID[x@ord],
+                  seq_along(x@ord), sorted_id,
                   function(idx) {
                       sub_time1 <- sorted_dat[idx, "time1"]
                       sub_time2 <- sorted_dat[idx, "time2"]
@@ -473,7 +465,7 @@ setMethod(f = "as.character", signature = "Recur",
                       sub_sign[length(idx)] <- sub_end
                       out <- sprintf(fmt, sub_time1,
                                      sub_time2, sub_sign)
-                      char_id <- sprintf("%s:", x@ID[idx[1L]])
+                      char_id <- sprintf("%s:", sorted_id[idx[1L]])
                       out_char <- if (length(sub_time1) > max_print) {
                                       paste(c(out[seq_len(max_print - 1)],
                                               "...",
